@@ -4,9 +4,9 @@ from ...plugin import Plugin
 
 
 class NotesPlugin(Plugin):
-    name = "notes"
+    identity = "notes"
     priority = 50
-    profile = {
+    validity = {
         "type": "object",
         "properties": {
             "format": {"type": "string"},
@@ -15,11 +15,11 @@ class NotesPlugin(Plugin):
 
     # Context
 
-    @Plugin.property
+    @property
     def format(self):
         return self.config.get("format", "%Y-%m-%d %H:%M")
 
-    @Plugin.property
+    @property
     def current(self):
         return datetime.fromtimestamp(os.path.getmtime(self.document.source))
 
