@@ -35,6 +35,11 @@ port = Option(
     help="Server port",
 )
 
+task = Argument(
+    None,
+    help="A task id",
+)
+
 
 # Command
 
